@@ -16,6 +16,7 @@ from .attributes.collections import (
     SmallListAttribute,
 )
 from .attributes.counter import CounterAttribute
+from .attributes.enum import EnumAttribute
 from .attributes.files import (
     FileAttribute,
     FileObject,
@@ -27,6 +28,7 @@ from .attributes.models import (
     ModelAttribute,
     InlineModelAttribute,
     IndexedModelAttribute,
+    ReverseModelAttribute,
 )
 from .attributes.password import PasswordAttribute
 from .attributes.simples import (
@@ -64,6 +66,7 @@ from .models import (
     IntIndexedModel,
     IntIndexedNamedAttributesModel,
     IntOrderedNamedAttributesModel,
+    IntOrderedIndexedModel,
     Model,
     UUIDIndexedDatedNamedAttributesModel,
     UUIDIndexedModel,
