@@ -1,13 +1,13 @@
 import itertools
 import operator
 from collections import OrderedDict
+from collections.abc import Iterable
 
 from BTrees.OOBTree import OOTreeSet, union, intersection, difference
 
 import sheraf.constants
 from sheraf.exceptions import InvalidFilterException, InvalidOrderException
 from sheraf.tools.more_itertools import unique_everseen
-from collections.abc import Iterable, Sized
 
 
 class QuerySet(object):
@@ -102,13 +102,22 @@ class QuerySet(object):
         return self
 
     def __repr__(self):
+        result = "<QuerySet"
         if self.model:
-            return "<QuerySet model={}>".format(self.model.__name__)
+            result = f"{result} model={self.model.__name__}"
 
         if self._iterable:
-            return "<QuerySet iterable={}>".format(self._iterable)
+            result = f"{result} iterable={self._iterable}"
 
-        return "<QuerySet>"
+        if self._predicate:
+            result = f"{result} predicate={self._predicate}"
+
+        if self.filters:
+            filters = ", ".join(f"{k}={v[1]}" for k, v in self.filters.items())
+            result = f"{result} filters=({filters})"
+
+        result = f"{result}>"
+        return result
 
     def __next__(self):
         if not self._iterator:
@@ -135,6 +144,14 @@ class QuerySet(object):
     def __xor__(self, other):
         return QuerySet(difference(OOTreeSet(self), OOTreeSet(other)))
 
+    def __bool__(self):
+        try:
+            next(self)
+            self._iterator = None
+            return True
+        except StopIteration:
+            return False
+
     def __getitem__(self, item):
         qs = self.copy()
 
@@ -145,6 +162,9 @@ class QuerySet(object):
 
         return qs
 
+    def __len__(self):
+        return self.copy().count()
+
     @property
     def indexed_filters(self):
         return [
@@ -296,6 +316,8 @@ class QuerySet(object):
         index = self.model.indexes[index_name]
         if filter_search_func:
             index_values = index.details.call_search_func(self.model, filter_value)
+        else:
+            index_values = filter_value
 
         if index.details.unique:
             return sum(int(index.has_item(v)) for v in index_values)
@@ -564,15 +586,11 @@ class QuerySet(object):
         try:
             element = next(self)
         except StopIteration:
-            raise sheraf.exceptions.EmptyQuerySetUnpackException(
-                "Trying to unpack an empty QuerySet"
-            )
+            raise sheraf.exceptions.EmptyQuerySetUnpackException()
 
         try:
             next(self)
         except StopIteration:
             return element
         else:
-            raise sheraf.exceptions.QuerySetUnpackException(
-                "Trying to unpack more than 1 value from a QuerySet"
-            )
+            raise sheraf.exceptions.QuerySetUnpackException()
